jactorch.nn.losses
==================

.. automodule:: jactorch.nn.losses

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      AverageLoss
      BinaryCrossEntropyLossWithProbs
      CompatibleCrossEntropyLossWithProbs
      CompatibleMSEProbabilityLoss
      CosineLoss
      CrossEntropyLoss
      CrossEntropyLossWithLogits
      CrossEntropyLossWithProbs
      LossAverageMethod
      MSELoss
      PNBalancedBinaryCrossEntropyLossWithProbs
      SmoothL1Loss
   
   

   
   
   

   
   
   








.. rubric:: Class AverageLoss
.. autoclass:: AverageLoss
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class BinaryCrossEntropyLossWithProbs
.. autoclass:: BinaryCrossEntropyLossWithProbs
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class CompatibleCrossEntropyLossWithProbs
.. autoclass:: CompatibleCrossEntropyLossWithProbs
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class CompatibleMSEProbabilityLoss
.. autoclass:: CompatibleMSEProbabilityLoss
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class CosineLoss
.. autoclass:: CosineLoss
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class CrossEntropyLoss
.. autoclass:: CrossEntropyLoss
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class CrossEntropyLossWithLogits
.. autoclass:: CrossEntropyLossWithLogits
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class CrossEntropyLossWithProbs
.. autoclass:: CrossEntropyLossWithProbs
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class LossAverageMethod
.. autoclass:: LossAverageMethod
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MSELoss
.. autoclass:: MSELoss
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class PNBalancedBinaryCrossEntropyLossWithProbs
.. autoclass:: PNBalancedBinaryCrossEntropyLossWithProbs
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class SmoothL1Loss
.. autoclass:: SmoothL1Loss
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







